@@ -23,7 +23,7 @@ def get_dict_from_instruction(instructions):
                 new_instructions[key] = new_instruction
     return new_instructions
 class InstructionManager:
-    def __init__(self,instructions=None)->None:
+    def __init__(self,instructions=None,instruction_bools={})->None:
         self.default_instructions = {
                     "api_response": {
                         "instruction": "Place response to prompt here.",
@@ -68,6 +68,8 @@ class InstructionManager:
                     }
         self.instructions = [[]]
         self.default_instructions.update(get_dict_from_instruction(instructions))
+        for key,value in instruction_bools.items():
+            self.default_instructions[key]['defaut'] = value
         self.update_instructions(0,**{key:self.default_instructions[key] for key in self.default_instructions if self.default_instructions[key].get('default')})
     def get_instructions(self,instruction_number:int=None)->dict:
         if len(self.instructions)==0:
